#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Python test bench for determination of the T1 parameters
- Use source identifier 'V1'
- Use load resistor value 'R_ell'
- Use the same file name for the .asc, .cir, .PNG, and .SVG
  files associated with a circuit.
"""
from SLiCAP import *

# Create a list with circuit file names if you want to run multiple circuits.
fileName = 'ABCDantenna'
    
#makeNetlist(fileName + '.asc', fileName)

# Define an instruction
i1 = instruction()
i1.setCircuit(fileName + '.cir')

i1.setSimType('symbolic')
i1.setGainType('gain')
i1.setDataType('laplace')

# Use the same identifier for the source in all files
i1.setSource('V1')

# Define the detector for determination of the input voltage
i1.setDetector('V_i')
result = i1.execute()
# V_i is the transfer from V1 to the voltage V_i at node i
V_i = result.laplace

# Define the detector for determination of the input current
i1.setDetector('I_V1')
result = i1.execute()
# I_i is the transfer from V1 to the current through V1
I_i = -result.laplace

# Define the detector for determination of the output voltage
i1.setDetector('V_o')
result = i1.execute()
# V_o is the transfer from V1 to the output voltage
V_o = result.laplace

# Define the detector for determination of the output current
i1.setDetector('I_R3')
result = i1.execute()
# I_o is the transfer from V1 to the current through R2
I_o = result.laplace

# Calculate the T1 parameters
# Use the same name for the load resistance in all files
R_ell = sp.Symbol('R_ell')
A     = sp.simplify(sp.limit(V_i/V_o, R_ell, 'oo'))
B     = sp.simplify(sp.limit(V_i/I_o, R_ell, 0))
C     = sp.simplify(sp.limit(I_i/V_o, R_ell, 'oo'))
D     = sp.simplify(sp.limit(I_i/I_o, R_ell, 0))

htmlPage('Determination of T1 matrix parameters')
head2html('Test circuit')
img2html(fileName + '.svg', 500)
head2html('T1 matrix of the device under test')
text2html('The T1 matrix of the device under test is found as:')
T1 = sp.Matrix([[A,B], [C,D]])
eqn2html('T_1', T1)
ViIi = sp.Matrix([[sp.Symbol('V_i')], [sp.Symbol('I_i')]])
VoIo = sp.Matrix([[sp.Symbol('V_o')], [sp.Symbol('I_o')]])
# Display the matrix equation without execution of the multiplication
text2html('The matrix equation for the two-port (DUT) is found as:')
text2html('$$' + sp.latex(ViIi) + "=" + sp.latex(T1) + '\\cdot' + sp.latex(VoIo) + '$$')
